# MIT License
#
# Copyright (c) 2018 Evgeny Medvedev, evge.medvedev@gmail.com
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.
import logging

from cli.base.executors.batch_work_executor import BatchWorkExecutor
from cli.base.jobs.base_job import BaseJob

logger = logging.getLogger(__name__)


class MultiThreadsJob(BaseJob):
    def __init__(
            self,
            work_iterable,
            batch_size,
            item_exporter,
            max_workers):
        self.item_exporter = item_exporter
        self.work_iterable = work_iterable
        self.batch_work_executor = BatchWorkExecutor(batch_size, max_workers)

        self._dict_cache = []

    def _start(self):
        self.item_exporter.open()

    def _export(self):
        self.batch_work_executor.execute(
            self.work_iterable,
            self._export_batch,
            total_items=len(self.work_iterable)
        )

    def _export_batch(self, work_data):
        # handler work
        pass

    def _end(self):
        self.batch_work_executor.shutdown()
        self.item_exporter.close()

    def get_cache(self):
        return self._dict_cache

    def clean_cache(self):
        self._dict_cache = []



import json

import click

from cli.check_multithread import MultiThreadsTelnetJob


@click.command(context_settings=dict(help_option_names=['-h', '--help']))
@click.option('-i', '--input', default="check_port_list.txt", type=str, help='input file Default : check_port_list.txt.')
@click.option('-o', '--output', default ="check_port_result.json", type=str, help='output file Default : check_port_result.json.')
@click.option('-n', '--number-thread', default=100, show_default=True, type=int, help='End block/ISO date/Unix time.')
def check_ports(input,output,number_thread):
    work_data = []
    with open(input, "r") as f:
        lines = f.readlines()
        for line in lines:
            work_data.append(line)
    job = MultiThreadsTelnetJob(work_iterable=work_data, max_workers=number_thread)

    job.run()
    result = job.get_result()

    # Serializing json
    json_object = json.dumps(result, indent=4)

    # Writing to sample.json
    with open(output, "w") as outfile:
        outfile.write(json_object)

@click.group()
@click.version_option(version='2.3.0')
@click.pass_context
def cli(ctx):
    pass


# export
cli.add_command(check_ports, "check_ports")

cli()